pub const fn left_encode(x: usize) -> LeftEncodeExpand description
Encodes x as a byte string in a way that can be
unambiguously parsed from the beginning.
pub const fn left_encode(x: usize) -> LeftEncodeEncodes x as a byte string in a way that can be
unambiguously parsed from the beginning.