pub const fn right_encode(x: usize) -> RightEncodeExpand description
Encodes x as a byte string in a way that can be
unambiguously parsed from the end.
pub const fn right_encode(x: usize) -> RightEncodeEncodes x as a byte string in a way that can be
unambiguously parsed from the end.