pub fn left_encode(__arg0: usize) -> LeftEncodeExpand description
Encodes x as a byte string in a way that can be
unambiguously parsed from the beginning.
pub fn left_encode(__arg0: usize) -> LeftEncodeEncodes x as a byte string in a way that can be
unambiguously parsed from the beginning.