pub fn right_encode(__arg0: usize) -> RightEncodeExpand description
Encodes x as a byte string in a way that can be
unambiguously parsed from the end.
pub fn right_encode(__arg0: usize) -> RightEncodeEncodes x as a byte string in a way that can be
unambiguously parsed from the end.